@@ -36,13 +36,19 @@ class BasicConfigure(BasicCommand):
     def _run_main(self, parsed_args, parsed_globals):
         raise NotImplementedError("_run_main")
 
+    def _get_profile_name(self, parsed_globals):
+        if parsed_globals.profile:
+            return parsed_globals.profile
+        profile_name = os.environ.get("TCCLI_PROFILE", "default")
+        return profile_name
+
     def _init_configure(self, profile_name, input_data, extra={}):
         conf_data = {}
         is_exist, config_path = self._profile_existed(profile_name)
         if is_exist:
             conf_data = Utils.load_json_msg(config_path)
 
-        if OptionsDefine.SysParam not in conf_data:
+        if profile_name.endswith(".configure") and OptionsDefine.SysParam not in conf_data:
             conf_data[OptionsDefine.SysParam] = {}
 
         for _sys_param in self.config_list:
@@ -106,7 +112,7 @@ class BasicConfigure(BasicCommand):
 
 class ConfigureListCommand(BasicConfigure):
     NAME = 'list'
-    DESCRIPTION = 'list your profile(eg:secretId, secretKey, region, output, language).'
+    DESCRIPTION = 'list your profile(eg:secretId, secretKey, region, output).'
     USEAGE = 'tccli configure list [--profile profile-name]'
     EXAMPLES = "$ tccli configure list\n" \
                "credential:\n" \
@@ -126,8 +132,7 @@ class ConfigureListCommand(BasicConfigure):
         self._stream = stream
 
     def _run_main(self, args, parsed_globals):
-        profile_name = parsed_globals.profile \
-            if parsed_globals.profile else "default"
+        profile_name = self._get_profile_name(parsed_globals)
 
         is_exit, cred_path = self._profile_existed(profile_name + ".credential")
         self._stream.write("credential:\n")
@@ -150,7 +155,7 @@ class ConfigureListCommand(BasicConfigure):
             for c in modlist:
                 if not config[c]:
                     continue
-                if c in self.config_list:
+                if c == OptionsDefine.SysParam:
                     continue
                 try:
                     self._stream.write("%s.version = %s\n" % (c, config[c]["version"]))
@@ -200,8 +205,7 @@ class ConfigureSetCommand(BasicConfigure):
         varnames = varname_value[::2]
         values = varname_value[1::2]
 
-        profile_name = parsed_globals.profile \
-            if parsed_globals.profile else "default"
+        profile_name = self._get_profile_name(parsed_globals)
 
         config = {}
         cred = {}
@@ -260,8 +264,7 @@ class ConfigureGetCommand(BasicConfigure):
 
     def _run_main(self, args, parsed_globals):
         varname_list = args.varname
-        profile_name = parsed_globals.profile \
-            if parsed_globals.profile else "default"
+        profile_name = self._get_profile_name(parsed_globals)
 
         conf = {}
         cred = {}
@@ -301,8 +304,7 @@ class ConfigureRemoveCommand(BasicConfigure):
         self._error_stream = error_stream
 
     def _run_main(self, args, parsed_globals):
-        profile_name = parsed_globals.profile \
-            if parsed_globals.profile else "default"
+        profile_name = self._get_profile_name(parsed_globals)
 
         configure_name = profile_name + '.configure'
         credential_name = profile_name + '.credential'
@@ -358,8 +360,7 @@ class ConfigureCommand(BasicConfigure):
 
     def _run_main(self, parsed_args, parsed_globals):
         # tccli configure
-        profile_name = parsed_globals.profile \
-            if parsed_globals.profile else "default"
+        profile_name = self._get_profile_name(parsed_globals)
 
         config = {
             OptionsDefine.Region: "ap-guangzhou",
@@ -379,32 +380,37 @@ class ConfigureCommand(BasicConfigure):
         if is_conf_exist:
             conf_data = Utils.load_json_msg(config_path)
             for c in config:
-                if c in conf_data and conf_data[c]:
-                    config[c] = conf_data[c]
+                if OptionsDefine.SysParam in conf_data \
+                        and c in conf_data[OptionsDefine.SysParam] \
+                        and conf_data[OptionsDefine.SysParam][c]:
+                    config[c] = conf_data[OptionsDefine.SysParam][c]
         if is_cred_exist:
             cred_data = Utils.load_json_msg(cred_path)
             for c in cred:
                 if c in cred_data and cred_data[c]:
                     cred[c] = cred_data[c]
 
+        if OptionsDefine.SysParam not in conf_data:
+            conf_data[OptionsDefine.SysParam] = {}
+
         for index, prompt_text in self.VALUES_TO_PROMPT:
             if index in config:
                 response = self._compat_input("%s[%s]: " % (prompt_text, config[index]))
                 if index == OptionsDefine.Output and response not in ['json', 'text', 'table']:
                     if config[index] not in ['json', 'text', 'table']:
                         print('Output format must be json, text or table. Set as default: json')
-                        conf_data[index] = 'json'
+                        conf_data[OptionsDefine.SysParam][index] = 'json'
                     else:
-                        conf_data[index] = config[index]
+                        conf_data[OptionsDefine.SysParam][index] = config[index]
                 elif index == OptionsDefine.Region and not response:
                     if not config[index]:
                         print('Set region as default: %s' % config[index])
-                    conf_data[index] = config[index]
+                    conf_data[OptionsDefine.SysParam][index] = config[index]
                 else:
-                    conf_data[index] = response if response else config[index]
+                    conf_data[OptionsDefine.SysParam][index] = response if response else config[index]
             else:
                 response = self._compat_input(
-                    "%s[%s]: " % (prompt_text, "*"+cred[index][-4:] if cred[index]!="None" else cred[index]))
+                    "%s[%s]: " % (prompt_text, "*"+cred[index][-4:] if cred[index] != "None" else cred[index]))
                 cred_data[index] = response if response else cred[index]
 
         self._init_configure(profile_name + ".configure", conf_data)
@@ -416,10 +422,15 @@ class ConfigureCommand(BasicConfigure):
             config = {
                 "region": "ap-guangzhou",
                 "output": "json",
-                "array_count": 10,
+                "arrayCount": 10,
                 "warning": "off"
             }
         self._init_configure("default.configure", config)
+        for profile_name in os.listdir(self.cli_path):
+            if profile_name == "default.configure":
+                continue
+            if profile_name.endswith(".configure"):
+                self._init_configure(profile_name, {})
 
     def _compat_input(self, prompt):
         sys.stdout.write(prompt)
@@ -493,7 +504,3 @@ class ConfigureDocumentHandler(object):
         self.available_subcommand()
         self.available_config()
         self.example()
-
-
-
-
