@@ -8,9 +8,9 @@ import os
 import sys
 import six
 import signal
-import logging
-base = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
-sys.path.insert(0, base)
+from tccli.log import init
+from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
+
 try:
     reload(sys)  # Python 2.7
     sys.setdefaultencoding('utf8')
@@ -28,54 +28,67 @@ from tccli import __version__
 from tccli.exceptions import UnknownArgumentError, ConfigurationError, NoCredentialsError, NoRegionError, ClientError
 from tccli.error_msg import USAGE
 
-LOG = logging.getLogger('tccli.main')
-LOG_FORMAT = ('%(asctime)s - %(threadName)s - %(name)s - %(levelname)s - %(message)s')
+log = init('tccli.main')
 
 
 def main():
     cli_version = __version__.rsplit(".", 1)[0]
-    if sdkVersion < cli_version:
+    if int(sdkVersion.split(".")[-1]) < int(cli_version.split(".")[-1]):
         sys.stderr.write("Version is inconsistent, python sdk version:%s tccli version:%s" % (sdkVersion, __version__))
-        return
+        return 255
     try:
-        LOG.debug("begin cli command")
+        log.info("tccli %s" % ' '.join(sys.argv[1:]))
         CLICommand()()
+        return 0
     except UnknownArgumentError as e:
         sys.stderr.write("usage: %s\n" % USAGE)
         sys.stderr.write(str(e))
         sys.stderr.write("\n")
-        return
+        log.exception(e)
+        return 255
     except ConfigurationError as e:
         sys.stderr.write("usage: %s\n" % USAGE)
         sys.stderr.write(str(e))
         sys.stderr.write("\n")
-        return
+        log.exception(e)
+        return 255
     except NoRegionError as e:
         msg = ('%s You can configure your region by running '
                '"tccli configure".' % e)
         sys.stderr.write(msg)
         sys.stderr.write('\n')
-        return
+        log.exception(e)
+        return 255
     except NoCredentialsError as e:
         msg = ('%s. You can configure your credentials by running '
                '"tccli configure".' % e)
         sys.stderr.write(msg)
         sys.stderr.write('\n')
-        return
+        log.exception(e)
+        return 255
     except KeyboardInterrupt:
         sys.stdout.write("\n")
-        return
+        return 255
     except ClientError as e:
         sys.stderr.write("\n")
         sys.stderr.write(six.text_type(e))
         sys.stderr.write("\n")
-        return
+        log.exception(e)
+        return 255
+    except TencentCloudSDKException as e:
+        sys.stderr.write("usage: %s\n" % USAGE)
+        sys.stderr.write(str(e))
+        sys.stderr.write("\n")
+        log.error(e)
+        return 255
     except Exception as e:
         sys.stderr.write("usage: %s\n" % USAGE)
         sys.stderr.write(str(e))
         sys.stderr.write("\n")
-        return
+        log.exception(e)
+        return 255
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
+
