@@ -1,12 +1,22 @@
 # -*- coding: utf-8 -*-
 import os
-import imp
+try:
+    import imp
+except ImportError:  # py12
+    imp = None
+    import importlib
+    import importlib.machinery
 
 
 def action_caller(service):
     cur_path = os.path.dirname(os.path.abspath(__file__))
-    fp, pathname, desc = imp.find_module(service, [cur_path])
-    mod = imp.load_module("tccli.services." + service, fp, pathname, desc)
+    if imp:
+        fp, pathname, desc = imp.find_module(service, [cur_path])
+        mod = imp.load_module("tccli.services." + service, fp, pathname, desc)
+    else:
+        spec = importlib.machinery.PathFinder().find_spec(service, [cur_path])
+        mod = importlib.util.module_from_spec(spec)
+        spec.loader.exec_module(mod)
     return mod.action_caller
 
 
@@ -75,6 +85,9 @@ SERVICE_VERSIONS = {
     "cmq": [
         "2019-03-04"
     ],
+    "csip": [
+        "2022-11-21"
+    ],
     "cvm": [
         "2017-03-12"
     ],
